; ==============================================================================================================================================================================================
; create agents and global variables ===========================================================================================================================================================
; ==============================================================================================================================================================================================

turtles-own
[
  Ni                                               ; agent's state on the social distinction
  Si                                               ; agent's status belief
  ei*                                              ; average performance expectation that group members (including i) have for the agent
  Ei                                               ; average performance expectation that group members (including i) have for the agent transformed
  Ei_alpha                                         ; average performance expectation that group members (including i) have for the agent transformed and weighted by alpha
  Ei_beta                                          ; average performance expectation that group members (including i) have for the agent transformed and weighted by beta  
  
  ;auxiliary variables  
  e_ii                                             ; agent's performance expectation for itself; information about performance expectations for others are stored in a specific link breed defined below
] 

globals
[
  comp                                             ; comprehensiveness of the behavior interchange patterns in the group
  cons                                             ; consistency of the behavior interaction patterns in the group
  previous_cons                                    ; the value of cons in the preceding iteration
  changes_cons                                     ; the number of changes in cons
  r                                                ; the value of r
  largest_share_of_agents_with_status_belief       ; the largest share of agents that hold the state Si = A/-1 or Si = B/1
  interactant_1                                    ; the first interactant in a given simulation step
  interactant_2                                    ; the second interactant in a given simulation step
  
  ;auxiliary variables
  my-seed                                          ; needed when the random number generator is initialized
  high_comp_agent                                  ; indicates which of the two interactants assumed the higher competence role in the interaction
  low_comp_agent                                   ; indicates which of the two interactants assumed the lower competence role in the interaction
  interaction_counter                              ; controlles the number of interactions that take place per iteration
]

directed-link-breed     [dominance_ties dominance_tie]                         ; creates a breed of links that allows to track and visualize behavior interchange patterns in which one agent appears more competent than the other
undirected-link-breed   [neutral_ties neutral_tie]                             ; creates a breed of links that allows to visualize behavior interchange patterns in which the agents appear equally competent
directed-link-breed     [performance_expectations performance_expectation]     ; creates a breed of links that provides information about agents' performance expectations for other group members

; ==============================================================================================================================================================================================
; define link properties =======================================================================================================================================================================
; ==============================================================================================================================================================================================

dominance_ties-own
[
  weight               ; the weight of a link indicates the number of interactions in favor of the source agent
]

neutral_ties-own
[
  weight               ; always 0 and serves only visualization purposes
]

performance_expectations-own
[
  e_ij                 ; the weight of a link indicates the performance expectation that agent i has for agent j
]

; ==============================================================================================================================================================================================
; initialize model run =========================================================================================================================================================================
; ==============================================================================================================================================================================================

to setup
  __clear-all-and-reset-ticks                                     ; clear the world
  do_make_seed                                                    ; create a new seed for random number generation
  do_make_agents                                                  ; initializes agents
  do_initialize_performance_expectations                          ; initializes the ties among agents/agent variable that will store informations about performance expectations
  do_update_performance_expectations                              ; updating performance expectations that agents have for themselves and for others
  do_initialize_measures                                          ; initialize measures
  do_initialize_plots                                             ; initialize 0-axis in outcome plots
end

to do_make_seed
  ifelse seed_to_use = "random" 
    [  
      set my-seed new-seed                     ; generate a new seed
    ]  
    [
      set my-seed own_seed                     ; define own seed
    ]
    
  output-print word "Seed used:" my-seed       ; print the seed that is used
  random-seed my-seed                          ; use selected seed     
end

to do_make_agents
  create-turtles number_agents_A [set Ni -1 set Si 0 set color 8 set shape "triangle" set size 1] ; initialize agents that belong to category A/-1
  create-turtles number_agents_B [set Ni  1 set Si 0 set color 8 set shape "circle"  set size 1]  ; initialize agents that belong to category B/1
  layout-circle sort turtles 10                                                                   ; distribute agents on the world's surface
end

to do_initialize_performance_expectations
  ask turtles
  [
    let ego who
    ask turtles with [Ni != 0]
    [
      let alter who
      if ego != alter
      [
        create-performance_expectation-to turtle ego
        [
          hide-link
        ]
      ]
    ]
  ]
end

to do_initialize_measures
  set cons 0
  set changes_cons 0
  set previous_cons 0
  set r 0
  set largest_share_of_agents_with_status_belief 0
end

to do_initialize_plots
  set-current-plot "measures"
  set-current-plot-pen "axis"
  auto-plot-off
  plotxy 0 0
  plotxy 1000000000 0
  auto-plot-on  
end

; ==============================================================================================================================================================================================
; run the model ================================================================================================================================================================================
; ==============================================================================================================================================================================================

to go
  set interaction_counter 0                                           ; for ease of output generation, one iteration/tick can contain multiple interactions; this reduces the number of data points generated during longer simulation runs
  
  while [interaction_counter < interactions_per_tick]
  [
    do_update_Eis                                                     ; update agents' expectation standings based on the updated performance expectations  
    do_select_interactants                                            ; select two agents for interaction in the current iteration
    do_interaction                                                    ; let the selected agents interact
    do_upate_behavior_interchange_patterns                            ; based on the outcome of the interaction, update behavior interchange patterns
    do_calculate_comp                                                 ; calculate the measure comp
    do_calculate_cons                                                 ; calculate the measure cons
    do_calculate_r                                                    ; calculate the measure r
    do_update_status_beliefs                                          ; update agents' status beliefs    
    do_update_performance_expectations                                ; update agents' performance expectations based on the updated behavior interchange patterns
    do_calculate_largest_share_of_agents_with_status_belief           ; calculate the measure largest_share_of_agents_with_status_belief 
    set interaction_counter interaction_counter + 1                   ; record the numbers of interactions that have taken place
  ]
  
  tick                                                                ; increase the iteration/tick-counter by 1
  if ticks >= max_number_iterations [stop]                            ; stop the simulation run when the maximal number of iterations/ticks has been reached
end

to do_update_Eis
  ask turtles
  [
    let ego who
    set ei* (sum [e_ij] of performance_expectations with [end2 = turtle ego] + e_ii) / count turtles
    set Ei exp(ei*)/ (1 + exp(ei*))
  ]           
end

to do_select_interactants
  ask turtles
  [
    set Ei_alpha Ei ^ alpha
  ]  

  set interactant_1 nobody
  let lower_boundary_1 0
  let upper_boundary_1 0
  let pick_1 random-float (sum [Ei_alpha] of turtles)
  
  ask turtles
  [
    set upper_boundary_1 upper_boundary_1 + Ei_alpha
    if interactant_1 = nobody
    [
      ifelse (pick_1 > lower_boundary_1 and pick_1 <= upper_boundary_1)
      [
        set interactant_1 who
      ]
      [
        set lower_boundary_1 upper_boundary_1
      ]
    ]
  ]
  
  set interactant_2 nobody
  let lower_boundary_2 0
  let upper_boundary_2 0
  let pick_2 random-float (sum [Ei_alpha] of turtles with [who != [who] of turtle interactant_1])

  ask turtles with [who != [who] of turtle interactant_1]
  [
    set upper_boundary_2 upper_boundary_2 + Ei_alpha
    if interactant_2 = nobody
    [
      ifelse (pick_2 > lower_boundary_2 and pick_2 <= upper_boundary_2)
      [
        set interactant_2 who
      ]
      [
        set lower_boundary_2 upper_boundary_2
      ]
    ]
  ]    
end

to do_interaction
  ask turtle interactant_1
  [
    set Ei_beta Ei ^ beta
  ] 
  
  ask turtle interactant_2
  [
    set Ei_beta Ei ^ beta
  ]  

  set high_comp_agent nobody
  set low_comp_agent nobody
  let pick random-float (([Ei_beta] of turtle interactant_1) + ([Ei_beta] of turtle interactant_2))
  
  ifelse (pick <= [Ei_beta] of turtle interactant_1)
  [
    set high_comp_agent [who] of turtle interactant_1
    set low_comp_agent [who] of turtle interactant_2
  ]
  [
    set high_comp_agent [who] of turtle interactant_2
    set low_comp_agent [who] of turtle interactant_1
  ]
end

to do_upate_behavior_interchange_patterns
  ask turtle high_comp_agent
  [
    if (out-dominance_tie-neighbor? turtle low_comp_agent = TRUE)
    [
      ask dominance_ties with [end1 = turtle high_comp_agent and end2 = turtle low_comp_agent]
      [
        set weight weight + 1
      ]
    ]
    if (in-dominance_tie-neighbor? turtle low_comp_agent  = TRUE)
    [
      ask dominance_ties with [end1 = turtle low_comp_agent and end2 = turtle high_comp_agent]
      [
        set weight weight - 1
      ]
    ]
    if (in-dominance_tie-neighbor? turtle low_comp_agent  = FALSE) and (out-dominance_tie-neighbor? turtle low_comp_agent = FALSE)
    [
      ask turtle low_comp_agent
      [
        if neutral_tie-neighbor? turtle high_comp_agent = TRUE
        [
          ask neutral_tie-with turtle high_comp_agent
          [
            die
          ]
        ]
        create-dominance_tie-from turtle high_comp_agent 
        [
          set weight 1
          set color 15
        ]
      ]      
    ]
  ]

  ;if a dominance tie has reached the weigth 0, change it to a neutral tie
  ask dominance_ties with [weight = 0]
  [
    set breed neutral_ties
    set color 9.9 
    set weight 0 
  ]
  
  ;display tie weights
  ask dominance_ties [set label weight]
  ask neutral_ties [set label weight]
end

to do_calculate_comp
  set comp ((count dominance_ties with [[Ni] of end1 = 1 and [Ni] of end2 = -1]) + (count dominance_ties with [[Ni] of end1 = -1 and [Ni] of end2 =  1]) + (count neutral_ties with   [[Ni] of end1 = 1 and [Ni] of end2 = -1]) + (count neutral_ties with [[Ni] of end1 = -1 and [Ni] of end2 = 1])) / (count turtles with [Ni = 1] * count turtles with [Ni = -1])
end

to do_calculate_cons
  set previous_cons cons 
  set cons 0
  
  if (count dominance_ties with [[Ni] of end1 != [Ni] of end2]) != 0
  [
    set cons (((count dominance_ties with [[Ni] of end1 = 1 and [Ni] of end2 = -1]) - (count dominance_ties with [[Ni] of end1 = -1 and [Ni] of end2 = 1])) / ((count dominance_ties with [[Ni] of end1 != [Ni] of end2]) + (count neutral_ties with [[Ni] of end1 != [Ni] of end2])))
  ]

  if previous_cons <= 0 and cons > 0
  [
    set changes_cons changes_cons + 1
  ]
  
  if previous_cons >= 0 and cons < 0
  [
    set changes_cons changes_cons + 1
  ]   
end

to do_calculate_r
  set r ((r + comp * cons) / (1 + comp))
end

to do_update_status_beliefs 
  ask turtles 
    [
      if r >= c
      [
        if Si = 0  and random-float (1) <= a [set Si  1 set color 65]
        if Si = -1 and random-float (1) <= l [set Si  0 set color 8]
      ]
      if r <= (- 1 * c)
      [
        if Si = 0  and random-float (1) <= a [set Si -1 set color 15]
        if Si = 1  and random-float (1) <= l [set Si  0 set color 8]
      ]   
      if r > (- 1 * c) and r < c
      [
        if Si != 0  and random-float (1) <= l [set Si  0 set color 8]
      ]       
    ]     
end

to do_update_performance_expectations
  if (bips_matter = TRUE) and (beliefs_matter = TRUE)
  [
    ask turtles
    [
      let ego who
      ask turtles with [Ni != 0]
      [
        let alter who
        ask performance_expectations with [end1 = turtle ego and end2 = turtle alter]
        [
          if ([Ni] of turtle alter = [Si] of turtle ego)
          [     
            set e_ij (expectation_weight ^ (count [in-dominance_tie-neighbors] of turtle alter    ))     - (expectation_weight ^ (count [out-dominance_tie-neighbors] of turtle alter + 1))
          ]
          if ([Ni] of turtle alter != [Si] of turtle ego) and ([Si] of turtle ego != 0)
          [     
            set e_ij (expectation_weight ^ (count [in-dominance_tie-neighbors] of turtle alter + 1))     - (expectation_weight ^ (count [out-dominance_tie-neighbors] of turtle alter    ))
          ]
          if ([Si] of turtle ego = 0)
          [     
            set e_ij (expectation_weight ^ (count [in-dominance_tie-neighbors] of turtle alter    ))     - (expectation_weight ^ (count [out-dominance_tie-neighbors] of turtle alter    ))
          ]
        ]
      ]
      if ([Ni] of turtle ego = [Si] of turtle ego)
      [     
        set e_ii (expectation_weight ^ (count [in-dominance_tie-neighbors] of turtle ego    ))     - (expectation_weight ^ (count [out-dominance_tie-neighbors] of turtle ego + 1))
      ]
      if ([Ni] of turtle ego != [Si] of turtle ego) and ([Si] of turtle ego != 0)
      [     
        set e_ii (expectation_weight ^ (count [in-dominance_tie-neighbors] of turtle ego + 1))     - (expectation_weight ^ (count [out-dominance_tie-neighbors] of turtle ego    ))
      ]
      if ([Si] of turtle ego = 0)
      [     
        set e_ii (expectation_weight ^ (count [in-dominance_tie-neighbors] of turtle ego    ))     - (expectation_weight ^ (count [out-dominance_tie-neighbors] of turtle ego    ))
      ]
    ]
  ]
  
  if (bips_matter = TRUE) and (beliefs_matter = FALSE) 
  [
    ask turtles
    [
      let ego who
      ask turtles with [Ni != 0]
      [
        let alter who
        ask performance_expectations with [end1 = turtle ego and end2 = turtle alter]
        [
          set e_ij (expectation_weight ^ (count [in-dominance_tie-neighbors] of turtle alter    ))     - (expectation_weight ^ (count [out-dominance_tie-neighbors] of turtle alter    ))
        ]
      ]
      set e_ii (expectation_weight ^ (count [in-dominance_tie-neighbors] of turtle ego    ))     - (expectation_weight ^ (count [out-dominance_tie-neighbors] of turtle ego    ))
    ]
  ]
  
  if (bips_matter = FALSE) and (beliefs_matter = TRUE) 
  [
    ask turtles
    [
      let ego who
      ask turtles with [Ni != 0]
      [
        let alter who
        ask performance_expectations with [end1 = turtle ego and end2 = turtle alter]
        [
          if ([Ni] of turtle alter = [Si] of turtle ego)
          [     
            set e_ij (expectation_weight ^ (0)) - (expectation_weight ^ (1))
          ]
          if ([Ni] of turtle alter != [Si] of turtle ego) and ([Si] of turtle ego != 0)
          [     
            set e_ij (expectation_weight ^ (1)) - (expectation_weight ^ (0))
          ]
          if ([Si] of turtle ego = 0)
          [     
            set e_ij (expectation_weight ^ (0)) - (expectation_weight ^ (0))
          ]
        ]
      ]
      if ([Ni] of turtle ego = [Si] of turtle ego)
      [     
        set e_ii (expectation_weight ^ (0)) - (expectation_weight ^ (1))
      ]
      if ([Ni] of turtle ego != [Si] of turtle ego) and ([Si] of turtle ego != 0)
      [     
        set e_ii (expectation_weight ^ (1)) - (expectation_weight ^ (0))
      ]
      if ([Si] of turtle ego = 0)
      [     
        set e_ii (expectation_weight ^ (0)) - (expectation_weight ^ (0))
      ]      
    ]
  ]
      
  if (bips_matter = FALSE) and (beliefs_matter = FALSE) 
  [
    ask turtles
    [
      let ego who
      ask turtles with [Ni != 0]
      [
        let alter who
        ask performance_expectations with [end1 = turtle ego and end2 = turtle alter]
        [
          set e_ij 0
        ]
      ]
      set e_ii 0
    ]
  ]            
end

to do_calculate_largest_share_of_agents_with_status_belief
  ifelse count turtles with [Si = 0] != count turtles
  [
    ifelse count turtles with [Si = -1] > count turtles with [Si = 1] 
    [
      set largest_share_of_agents_with_status_belief  (count turtles with [Si = -1]) / (count turtles)
    ]
    [
      set largest_share_of_agents_with_status_belief  (count turtles with [Si =  1]) / (count turtles)
    ]    
  ]
  [
    set largest_share_of_agents_with_status_belief  0
  ] 
end
@#$#@#$#@
GRAPHICS-WINDOW
507
19
946
479
16
16
13.0
1
10
1
1
1
0
0
0
1
-16
16
-16
16
0
0
1
ticks
30.0

BUTTON
31
18
94
51
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
31
57
94
90
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
972
18
1332
174
measures
NIL
NIL
0.0
10.0
-1.0
1.0
true
true
"" ""
PENS
"cons" 1.0 0 -14454117 true "" "plot cons"
"comp" 1.0 0 -7858858 true "" "plot comp"
"r" 1.0 0 -5987164 true "" "plot r"
"axis" 1.0 0 -16777216 false "" ""

INPUTBOX
32
346
147
406
max_number_iterations
2000
1
0
Number

INPUTBOX
32
413
148
473
interactions_per_tick
1
1
0
Number

CHOOSER
32
104
124
149
seed_to_use
seed_to_use
"random" "own"
0

INPUTBOX
31
206
191
266
own_seed
-1960308979
1
0
Number

INPUTBOX
35
699
150
759
alpha
2.5
1
0
Number

SWITCH
624
621
741
654
bips_matter
bips_matter
0
1
-1000

SWITCH
748
621
865
654
beliefs_matter
beliefs_matter
0
1
-1000

INPUTBOX
34
788
148
848
beta
1
1
0
Number

OUTPUT
31
279
192
334
10

PLOT
973
178
1333
328
changes_cons
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"changes_cons" 1.0 0 -16777216 true "" "plot changes_cons"

PLOT
974
332
1334
482
largest_share_of_agents_with_status_belief
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot largest_share_of_agents_with_status_belief"

INPUTBOX
34
625
149
685
expectation_weight
0.8
1
0
Number

INPUTBOX
343
626
459
686
c
0.5
1
0
Number

INPUTBOX
343
690
459
750
a
0.5
1
0
Number

INPUTBOX
343
754
459
814
l
0.5
1
0
Number

PLOT
974
489
1335
639
distribution of beliefs
NIL
NIL
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"belief A" 1.0 1 -2674135 true "" "if ticks > 0\n[\n  plot (1)\n]"
"belief O" 1.0 1 -7500403 true "" "if ticks > 0\n[\n  plot (count turtles with [Si =  0] / count turtles) + (count turtles with [Si =  1] / count turtles)\n]"
"belief B" 1.0 1 -13840069 true "" "if ticks > 0\n[\n   plot (count turtles with [Si =  1] / count turtles)\n]"

INPUTBOX
32
525
148
585
number_agents_A
3
1
0
Number

INPUTBOX
157
525
273
585
number_agents_B
3
1
0
Number

TEXTBOX
133
103
283
201
Defines whether a new system- or a fixed user-defined seed should be used for initializing random numbers. Using a user-defined seed allows full reliability of runs.
11
0.0
1

TEXTBOX
100
27
250
45
Initialize the simulation run.
11
0.0
1

TEXTBOX
100
64
250
82
Start the simulation run.
11
0.0
1

TEXTBOX
203
209
353
227
User-defined seed.
11
0.0
1

TEXTBOX
202
281
352
309
Reports the seed that has been used.
11
0.0
1

TEXTBOX
156
345
306
387
Maximum number of iterations/ticks a simulation run should continue.
11
0.0
1

TEXTBOX
155
411
305
509
Number of interactions that should take place within each iteration/tick. The standard is 1, but for reducing the output generated in the case of longer runs, this number can be increased.
11
0.0
1

TEXTBOX
283
525
451
609
Number of agents who belong to the categories Ni = A and Ni = B. Technically, the states A and B are represented by -1 and 1, both in the case of Ni and Si; the state Si = O is represented as 0.
11
0.0
1

TEXTBOX
159
625
341
709
Value used for the base when calculating performance expectations (the standard is .8; submodel:  update_performance_expectations).
11
0.0
1

TEXTBOX
160
696
310
780
Weight used for determining effect of performance expectations on interaction probabilities (submodel: select_interactants).
11
0.0
1

TEXTBOX
161
786
311
870
Weight used for determining effect of performance expectations on the outcome of interactions (submodel: interaction).
11
0.0
1

TEXTBOX
470
628
620
670
Threshold for belief acquisition and loss (submodel: update_status_beliefs).
11
0.0
1

TEXTBOX
469
691
619
733
Probability of belief acquisition (submodel: update_status_beliefs).
11
0.0
1

TEXTBOX
470
761
621
803
Probability of belief loss (submodel: update_status_beliefs).
11
0.0
1

TEXTBOX
623
662
1000
816
Allows modifying the pieces of information considered when performance expectations are updated. When bips_matter = on/off, behavior interachange patterns are/are not considered. When beliefs_matter = on/off, agents' status beliefs are/are not considered. \n\nIn the random interaction model: bips_matter = off & beliefs_matter = off.\nIn the basic interaction model: bips_matter = on & beliefs_matter = off.\nIn the extended interaction model: bips_matter = on & beliefs_matter = on.\n\n(submodel: update_performance_expectations).\n
11
0.0
1

TEXTBOX
511
487
951
585
Legend: Triangles and circles and represent agents for which Ni = A and Ni = B respectively. Red, gray, and green coloring of agents represents Si = A, Si = O, and Si = B respectively. Directed red ties between agents indicate that a behavior interchange patterns has been established, in which the source holds the higher competence position and the sink holds the lower competence position. Undirected white ties indicate that the behavior interchange pattern currently is balanced. The weights of the ties are displayed next to them.\n
11
0.0
1

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.5
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="N4-[beliefs true] [bips true] [agents_B 2] [agents_A 2] [alpha 2.5] [beta 1] [expectation_weight 0.8] [c 0.5] [a 0.5] [l 0.5]" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>cons</metric>
    <metric>comp</metric>
    <metric>r</metric>
    <metric>changes_cons</metric>
    <metric>largest_share_of_agents_with_status_belief</metric>
    <metric>count turtles with [Si = -1]</metric>
    <metric>count turtles with [Si =  0]</metric>
    <metric>count turtles with [Si =  1]</metric>
    <enumeratedValueSet variable="seed_to_use">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="own_seed">
      <value value="-1960308979"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beliefs_matter">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bips_matter">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_B">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_A">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="expectation_weight">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_number_iterations">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interactions_per_tick">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="l">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N4-[beliefs false] [bips true] [agents_B 2] [agents_A 2] [alpha 2.5] [beta 1] [expectation_weight 0.8] [c 0.5] [a 0.5] [l 0.5]" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>cons</metric>
    <metric>comp</metric>
    <metric>r</metric>
    <metric>changes_cons</metric>
    <metric>largest_share_of_agents_with_status_belief</metric>
    <metric>count turtles with [Si = -1]</metric>
    <metric>count turtles with [Si =  0]</metric>
    <metric>count turtles with [Si =  1]</metric>
    <enumeratedValueSet variable="seed_to_use">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="own_seed">
      <value value="-1960308979"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beliefs_matter">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bips_matter">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_B">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_A">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="expectation_weight">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_number_iterations">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interactions_per_tick">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="l">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N4-[beliefs false] [bips false] [agents_B 2] [agents_A 2] [alpha 2.5] [beta 1] [expectation_weight 0.8] [c 0.5] [a 0.5] [l 0.5]" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>cons</metric>
    <metric>comp</metric>
    <metric>r</metric>
    <metric>changes_cons</metric>
    <metric>largest_share_of_agents_with_status_belief</metric>
    <metric>count turtles with [Si = -1]</metric>
    <metric>count turtles with [Si =  0]</metric>
    <metric>count turtles with [Si =  1]</metric>
    <enumeratedValueSet variable="seed_to_use">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="own_seed">
      <value value="-1960308979"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beliefs_matter">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bips_matter">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_B">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_A">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="expectation_weight">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_number_iterations">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interactions_per_tick">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="l">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N6-[beliefs true] [bips true] [agents_B 3] [agents_A 3] [alpha 2.5] [beta 1] [expectation_weight 0.8] [c 0.5] [a 0.5] [l 0.5]" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>cons</metric>
    <metric>comp</metric>
    <metric>r</metric>
    <metric>changes_cons</metric>
    <metric>largest_share_of_agents_with_status_belief</metric>
    <metric>count turtles with [Si = -1]</metric>
    <metric>count turtles with [Si =  0]</metric>
    <metric>count turtles with [Si =  1]</metric>
    <enumeratedValueSet variable="seed_to_use">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="own_seed">
      <value value="-1960308979"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beliefs_matter">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bips_matter">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_B">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="expectation_weight">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_number_iterations">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interactions_per_tick">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="l">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N6-[beliefs false] [bips true] [agents_B 3] [agents_A 3] [alpha 2.5] [beta 1] [expectation_weight 0.8] [c 0.5] [a 0.5] [l 0.5]" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>cons</metric>
    <metric>comp</metric>
    <metric>r</metric>
    <metric>changes_cons</metric>
    <metric>largest_share_of_agents_with_status_belief</metric>
    <metric>count turtles with [Si = -1]</metric>
    <metric>count turtles with [Si =  0]</metric>
    <metric>count turtles with [Si =  1]</metric>
    <enumeratedValueSet variable="seed_to_use">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="own_seed">
      <value value="-1960308979"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beliefs_matter">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bips_matter">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_B">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="expectation_weight">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_number_iterations">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interactions_per_tick">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="l">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N6-[beliefs false] [bips false] [agents_B 3] [agents_A 3] [alpha 2.5] [beta 1] [expectation_weight 0.8] [c 0.5] [a 0.5] [l 0.5]" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>cons</metric>
    <metric>comp</metric>
    <metric>r</metric>
    <metric>changes_cons</metric>
    <metric>largest_share_of_agents_with_status_belief</metric>
    <metric>count turtles with [Si = -1]</metric>
    <metric>count turtles with [Si =  0]</metric>
    <metric>count turtles with [Si =  1]</metric>
    <enumeratedValueSet variable="seed_to_use">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="own_seed">
      <value value="-1960308979"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beliefs_matter">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bips_matter">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_B">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_A">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="expectation_weight">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_number_iterations">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interactions_per_tick">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="l">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N8-[beliefs true] [bips true] [agents_B 4] [agents_A 4] [alpha 2.5] [beta 1] [expectation_weight 0.8] [c 0.5] [a 0.5] [l 0.5]" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>cons</metric>
    <metric>comp</metric>
    <metric>r</metric>
    <metric>changes_cons</metric>
    <metric>largest_share_of_agents_with_status_belief</metric>
    <metric>count turtles with [Si = -1]</metric>
    <metric>count turtles with [Si =  0]</metric>
    <metric>count turtles with [Si =  1]</metric>
    <enumeratedValueSet variable="seed_to_use">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="own_seed">
      <value value="-1960308979"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beliefs_matter">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bips_matter">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_B">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_A">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="expectation_weight">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_number_iterations">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interactions_per_tick">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="l">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N8-[beliefs false] [bips true] [agents_B 4] [agents_A 4] [alpha 2.5] [beta 1] [expectation_weight 0.8] [c 0.5] [a 0.5] [l 0.5]" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>cons</metric>
    <metric>comp</metric>
    <metric>r</metric>
    <metric>changes_cons</metric>
    <metric>largest_share_of_agents_with_status_belief</metric>
    <metric>count turtles with [Si = -1]</metric>
    <metric>count turtles with [Si =  0]</metric>
    <metric>count turtles with [Si =  1]</metric>
    <enumeratedValueSet variable="seed_to_use">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="own_seed">
      <value value="-1960308979"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beliefs_matter">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bips_matter">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_B">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_A">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="expectation_weight">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_number_iterations">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interactions_per_tick">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="l">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N8-[beliefs false] [bips false] [agents_B 4] [agents_A 4] [alpha 2.5] [beta 1] [expectation_weight 0.8] [c 0.5] [a 0.5] [l 0.5]" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>cons</metric>
    <metric>comp</metric>
    <metric>r</metric>
    <metric>changes_cons</metric>
    <metric>largest_share_of_agents_with_status_belief</metric>
    <metric>count turtles with [Si = -1]</metric>
    <metric>count turtles with [Si =  0]</metric>
    <metric>count turtles with [Si =  1]</metric>
    <enumeratedValueSet variable="seed_to_use">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="own_seed">
      <value value="-1960308979"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beliefs_matter">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bips_matter">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_B">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_A">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="expectation_weight">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_number_iterations">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interactions_per_tick">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="l">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N10-[beliefs false] [bips false] [agents_B 5] [agents_A 5] [alpha 2.5] [beta 1] [expectation_weight 0.8] [c 0.5] [a 0.5] [l 0.5]" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>cons</metric>
    <metric>comp</metric>
    <metric>r</metric>
    <metric>changes_cons</metric>
    <metric>largest_share_of_agents_with_status_belief</metric>
    <metric>count turtles with [Si = -1]</metric>
    <metric>count turtles with [Si =  0]</metric>
    <metric>count turtles with [Si =  1]</metric>
    <enumeratedValueSet variable="seed_to_use">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="own_seed">
      <value value="-1960308979"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beliefs_matter">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bips_matter">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_B">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_A">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="expectation_weight">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_number_iterations">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interactions_per_tick">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="l">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N10-[beliefs false] [bips true] [agents_B 5] [agents_A 5] [alpha 2.5] [beta 1] [expectation_weight 0.8] [c 0.5] [a 0.5] [l 0.5]" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>cons</metric>
    <metric>comp</metric>
    <metric>r</metric>
    <metric>changes_cons</metric>
    <metric>largest_share_of_agents_with_status_belief</metric>
    <metric>count turtles with [Si = -1]</metric>
    <metric>count turtles with [Si =  0]</metric>
    <metric>count turtles with [Si =  1]</metric>
    <enumeratedValueSet variable="seed_to_use">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="own_seed">
      <value value="-1960308979"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beliefs_matter">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bips_matter">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_B">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_A">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="expectation_weight">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_number_iterations">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interactions_per_tick">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="l">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="N10-[beliefs true] [bips true] [agents_B 5] [agents_A 5] [alpha 2.5] [beta 1] [expectation_weight 0.8] [c 0.5] [a 0.5] [l 0.5]" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <metric>cons</metric>
    <metric>comp</metric>
    <metric>r</metric>
    <metric>changes_cons</metric>
    <metric>largest_share_of_agents_with_status_belief</metric>
    <metric>count turtles with [Si = -1]</metric>
    <metric>count turtles with [Si =  0]</metric>
    <metric>count turtles with [Si =  1]</metric>
    <enumeratedValueSet variable="seed_to_use">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="own_seed">
      <value value="-1960308979"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beliefs_matter">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bips_matter">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_B">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number_agents_A">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="alpha">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="expectation_weight">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_number_iterations">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="interactions_per_tick">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="c">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="a">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="l">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
